Learn R Programming

RSPS (version 1.0)

poiss.pow: Estimates power for given sample size using simulation from Poisson distribution

Description

The function provides estimate of power for given sample size when there is no over-dispersion. The data is simulated from Poisson distribution.

Usage

poiss.pow(n, lambda1, k, alpha = 0.05, seed = 20, numsim = 2000, monitor = TRUE, sig = 3)

Arguments

n
A vector of positive integers representing the sample size
lambda1
Mean count under the null distribution. It can be a vector.
k
Fold change desired under the alternative distribution. It can be a vector.
alpha
Type I error rate: a value between 0 and 1. It can be a vector.
seed
Value of seed to ensure reproducibility of results.
numsim
Number of simulations. 1000 is recommended.
monitor
If TRUE, it allows us to view the progress of the function.
sig
Number of significant digits after decimal.

Value

Mean.Null
Mean Count under Null distribution.
Effect.Size
Fold Change Under the alternate hypothesis.
Power
Estimated Power.
Std.Err
Standard Error.

Details

The test statistic used is the scaled difference. Please contact the authors for more details on algorithm.

References

None

See Also

rpois

Examples

Run this code
#--------------------------------------------------
power.poiss <- poiss.pow(n=c(5,10,15),lambda1=c(3),k=c(2,3),
alpha=0.001,seed = 20,numsim=100,monitor=TRUE)
power.poiss
# Another example (takes longer to run)
#power.poiss <- poiss.pow(n=c(3,5,10,15),lambda1=c(3),k=c(2,2.5,3),
#alpha=0.001,seed = 20,numsim=1000,monitor=TRUE)
#power.poiss

Run the code above in your browser using DataLab